pub enum NumWorkers {
Default,
Manual(usize),
}Expand description
The number of workers that the server should start.
By default the number of available logical cpu cores is used. Takes a string value: Either “default”, or an integer N > 0 e.g. “6”.
Variants