Struct actix_settings::ActixSettings
source · [−]pub struct ActixSettings {Show 13 fields
pub hosts: Vec<Address>,
pub mode: Mode,
pub enable_compression: bool,
pub enable_log: bool,
pub num_workers: NumWorkers,
pub backlog: Backlog,
pub max_connections: MaxConnections,
pub max_connection_rate: MaxConnectionRate,
pub keep_alive: KeepAlive,
pub client_timeout: Timeout,
pub client_shutdown: Timeout,
pub shutdown_timeout: Timeout,
pub tls: Tls,
}Expand description
Settings types for Actix Web.
Fields
hosts: Vec<Address>List of addresses for the server to bind to.
mode: ModeMarker of intended deployment environment.
enable_compression: boolTrue if the Compress middleware should be enabled.
enable_log: boolTrue if the Logger middleware should be enabled.
num_workers: NumWorkersThe number of workers that the server should start.
backlog: BacklogThe maximum number of pending connections.
max_connections: MaxConnectionsThe per-worker maximum number of concurrent connections.
max_connection_rate: MaxConnectionRateThe per-worker maximum concurrent TLS connection limit.
keep_alive: KeepAliveServer keep-alive preference.
client_timeout: TimeoutTimeout duration for reading client request header.
client_shutdown: TimeoutTimeout duration for connection shutdown.
shutdown_timeout: TimeoutTimeout duration for graceful worker shutdown.
tls: TlsTLS (HTTPS) configuration.