Struct actix_settings::BasicSettings
source · [−]pub struct BasicSettings<A> {
pub actix: ActixSettings,
pub application: A,
}Expand description
Wrapper for server and application-specific settings.
Fields
actix: ActixSettingsActix Web server settings.
application: AApplication-specific settings.
Implementations
sourceimpl<A> BasicSettings<A> where
A: DeserializeOwned,
impl<A> BasicSettings<A> where
A: DeserializeOwned,
sourcepub fn parse_toml<P>(filepath: P) -> AtResult<Self> where
P: AsRef<Path>,
pub fn parse_toml<P>(filepath: P) -> AtResult<Self> where
P: AsRef<Path>,
Parse an instance of Self from a TOML file located at filepath.
If the file doesn’t exist, it is generated from the default TOML template, after which the newly generated file is read in and parsed.
sourcepub fn from_default_template() -> AtResult<Self>
pub fn from_default_template() -> AtResult<Self>
Parse an instance of Self straight from the default TOML template.
sourcepub fn from_template(template: &str) -> AtResult<Self>
pub fn from_template(template: &str) -> AtResult<Self>
Parse an instance of Self straight from the default TOML template.
sourcepub fn write_toml_file<P>(filepath: P) -> AtResult<()> where
P: AsRef<Path>,
pub fn write_toml_file<P>(filepath: P) -> AtResult<()> where
P: AsRef<Path>,
Writes the default TOML template to a new file, located at filepath.
Errors
Returns a FileExists error if a file already exists at that
location.
sourcepub fn override_field<F, V>(field: &mut F, value: V) -> AtResult<()> where
F: Parse,
V: AsRef<str>,
pub fn override_field<F, V>(field: &mut F, value: V) -> AtResult<()> where
F: Parse,
V: AsRef<str>,
Attempts to parse value and override the referenced field.
Examples
use actix_settings::{Settings, Mode};
let mut settings = Settings::from_default_template()?;
assert_eq!(settings.actix.mode, Mode::Development);
Settings::override_field(&mut settings.actix.mode, "production")?;
assert_eq!(settings.actix.mode, Mode::Production);sourcepub fn override_field_with_env_var<F, N>(
field: &mut F,
var_name: N
) -> AtResult<()> where
F: Parse,
N: AsRef<str>,
pub fn override_field_with_env_var<F, N>(
field: &mut F,
var_name: N
) -> AtResult<()> where
F: Parse,
N: AsRef<str>,
Attempts to read an environment variable, parse it, and override the referenced field.
Examples
use actix_settings::{Settings, Mode};
std::env::set_var("OVERRIDE__MODE", "production");
let mut settings = Settings::from_default_template()?;
assert_eq!(settings.actix.mode, Mode::Development);
Settings::override_field_with_env_var(&mut settings.actix.mode, "OVERRIDE__MODE")?;
assert_eq!(settings.actix.mode, Mode::Production);Trait Implementations
sourceimpl<A: Clone> Clone for BasicSettings<A>
impl<A: Clone> Clone for BasicSettings<A>
sourcefn clone(&self) -> BasicSettings<A>
fn clone(&self) -> BasicSettings<A>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<A: Debug> Debug for BasicSettings<A>
impl<A: Debug> Debug for BasicSettings<A>
sourceimpl<'de, A> Deserialize<'de> for BasicSettings<A> where
A: Deserialize<'de>,
impl<'de, A> Deserialize<'de> for BasicSettings<A> where
A: Deserialize<'de>,
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<A: Hash> Hash for BasicSettings<A>
impl<A: Hash> Hash for BasicSettings<A>
sourceimpl<A: PartialEq> PartialEq<BasicSettings<A>> for BasicSettings<A>
impl<A: PartialEq> PartialEq<BasicSettings<A>> for BasicSettings<A>
sourcefn eq(&self, other: &BasicSettings<A>) -> bool
fn eq(&self, other: &BasicSettings<A>) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &BasicSettings<A>) -> bool
fn ne(&self, other: &BasicSettings<A>) -> bool
This method tests for !=.
impl<A: Eq> Eq for BasicSettings<A>
impl<A> StructuralEq for BasicSettings<A>
impl<A> StructuralPartialEq for BasicSettings<A>